Module v1alpha

Module v1alpha 

Modules

device_plugin_client
Generated client implementations.
device_plugin_server
Generated server implementations.
registration_client
Generated client implementations.
registration_server
Generated server implementations.

Structs

AllocateRequest
Allocate is expected to be called during pod creation since allocation failures for any container would result in pod startup failure.Allocate allows kubelet to exposes additional artifacts in a pod’s environment as directed by the plugin.Allocate allows Device Plugin to run device specific operations on the Devices requested
AllocateResponse
AllocateResponse includes the artifacts that needs to be injected into a container for accessing ‘deviceIDs’ that were mentioned as part of ‘AllocateRequest’. Failure Handling: if Kubelet sends an allocation request for dev1 and dev2. Allocation on dev1 succeeds but allocation on dev2 fails. The Device plugin should send a ListAndWatch update and fail the Allocation request
Device
E.g: struct Device { ID: “GPU-fef8089b-4820-abfc-e83e-94318197576e”, Health: “Healthy”, }
DeviceSpec
DeviceSpec specifies a host device to mount into a container.
Empty
ListAndWatchResponse
ListAndWatch returns a stream of List of Devices Whenever a Device state changes or a Device disappears, ListAndWatch returns the new list
Mount
Mount specifies a host volume to mount into a container. where device library or tools are installed on host and container
RegisterRequest

Constants

DEVICE_PLUGIN_PATH
The folder the Device Plugin is expecting sockets to be on. Only privileged pods have access to this path. Note: Placeholder until we find a “standard path”.
HEALTHY
Means that the device is healthy.
KUBELET_SOCKET
The path of the Kubelet registry socket.
UNHEALTHY
Means that the device is unhealthy.