Allocate is expected to be called during pod creation since allocation
failures for any container would result in pod startup failure.Allocate allows kubelet to exposes additional artifacts in a pod’s
environment as directed by the plugin.Allocate allows Device Plugin to run device specific operations on
the Devices requested
AllocateResponse includes the artifacts that needs to be injected into
a container for accessing ‘deviceIDs’ that were mentioned as part of
‘AllocateRequest’.
Failure Handling:
if Kubelet sends an allocation request for dev1 and dev2.
Allocation on dev1 succeeds but allocation on dev2 fails.
The Device plugin should send a ListAndWatch update and fail the
Allocation request
The folder the Device Plugin is expecting sockets to be on. Only
privileged pods have access to this path. Note: Placeholder until we
find a “standard path”.